Contributing
============

You're welcome to come and bake delicious macaroons with us :)

This project uses uv_ and pre-commit_.

.. _uv: https://docs.astral.sh/uv/
.. _pre-commit: https://pre-commit.com

I want to run the CI checks locally
-----------------------------------

.. code-block:: console

    $ scripts/tests
    $ scripts/lint
    $ scripts/docs

Please inspect those scripts, you'll see that they are very short. You're free to
use the command they describe directly, there's nothing wrong in that.
